summaryrefslogtreecommitdiffstats
path: root/kalzium/src/spectrumviewimpl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kalzium/src/spectrumviewimpl.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalzium/src/spectrumviewimpl.h')
-rw-r--r--kalzium/src/spectrumviewimpl.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kalzium/src/spectrumviewimpl.h b/kalzium/src/spectrumviewimpl.h
index ed02db85..aea5ad2a 100644
--- a/kalzium/src/spectrumviewimpl.h
+++ b/kalzium/src/spectrumviewimpl.h
@@ -23,13 +23,14 @@
class SpectrumViewImpl : public SpectrumView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent the parent widget
* @param name the name used internally
*/
- SpectrumViewImpl( TQWidget* parent, const char* name );
+ SpectrumViewImpl( TQWidget* tqparent, const char* name );
/**
* sets the spectrum to @p spec
@@ -23,13 +23,14 @@
public:
/**
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param name the name used internally
*/